@@ -24,6 +24,8 @@ pub enum Error {
     ExpectedInt,
     #[error("Variable not found")]
     VarNotFound,
+    #[error("Cannot execute a path on a value")]
+    PathOnValue,
     #[error("Input is empty in {0}")]
     Empty(&'static str),
 }
@@ -210,6 +212,9 @@ impl<'a, 'q> Iterator for NodeOrValueIter<'a, 'q> {
 }
 
 pub trait Queryable<'q> {
+    fn keys(&self) -> ValueIter<'_> {
+        ValueIter::empty()
+    }
     fn member<'a, 'f>(&'a self, _: &'f Value) -> Option<Node<'a, 'q>> {
         None
     }
